@@ -318,7 +318,7 @@ class TextPreprocessor:
             'ERROR: document "{}" has not exist'.format(doc_id)
         doc = self._corpus[doc_id]
         pars_ = doc.setdefault('pars', [])
-        par_no1 = len(pars)
+        par_no1 = len(pars_)
         par_no2 = par_no1 - 1
         for i, text in enumerate(
             self.text_to_pars(pars, eop=eop) if isinstance(pars, str) else
@@ -332,6 +332,7 @@ class TextPreprocessor:
                 pars_.append({'text': self.RE_LF2.sub(
                     r'\g<1> \g<2>', self.RE_LF.sub(r'\g<1> ', text)
                 ).replace('\n', '. ').replace('\r', '')})
+                par_no2 += 1
         return (par_no1, par_no2) if par_no2 >= par_no1 else (None, None)
 
     def load_pars(self, path, encoding='utf-8-sig', eop=r'\n', doc_id=None):
@@ -713,20 +714,19 @@ class TextPreprocessor:
                 else: # maybehyphen in [1, 2]
                     isknown = wform_isknown(word)
                     ## если и предыдущее, и текущее слово известны
-                    #print('[', end='')
-                    if maybehyphen == 1 or isknown:
-                        # если автор не добавлял пробелов, то и мы не будем
-                        #print(hyphens[i-1], end='')
-                        if hyphens[i-1] == '-': # safe... I think %)
-                            res += '-' + word
-                            #maybehyphen = 1
-                        else:
-                            res += ' - ' + word
-                            maybehyphen = 2
+                    if maybehyphen == 1 and isknown:
+                        ## если автор не добавлял пробелов, то и мы не будем
+                        #if hyphens[i-1] == '-': # safe... I think %)
+                        #    res += '-' + word
+                        #    #maybehyphen = 1
+                        #else:
+                        #    res += ' - ' + word
+                        #    maybehyphen = 2
+                        res += ' - ' + word
+                        maybehyphen = 1
                     ## если хотя бы одно слово неизвестно, то дефис
                     else:
                         res += '-' + word
-                    #print(']:', end='')
 
             while True:
                 has1more = i > 0
@@ -770,7 +770,7 @@ class TextPreprocessor:
             return res + ' '
 
         # находим все слова c дефисами; с одной стороны от дефиса м.б. пробел
-        re_sub(r'\w+(?:(?:-| -|- )\w+)+', process, text)
+        text = re_sub(r'\w+(?:(?:-| -|- )\w+)+', process, text)
 
         return text
 
@@ -932,8 +932,8 @@ class TextPreprocessor:
         :param ignore_case: do not consider character case during processing
 
         :param silent: suppress log
-        :param sent_no: init value for the progress indicator
-                        (if silent != False)
+        :param sent_no: init value for the progress indicator (has effect if
+                        silent is False)
         :param tags: storage for found tags
         :type tags: dict(tag, value)
         """
